@@ -17,11 +17,14 @@
 
 """Fact Editing State Machine"""
 
+from gettext import gettext as _
+
 from collections import namedtuple
 
 from nark.items.fact import Fact
 
-from dob_bright.termio.style import colorize, set_coloring
+from dob_bright.termio import dob_in_user_warning
+from dob_bright.termio.style import stylize, set_coloring, verify_colors_attrs
 
 from ..ptkui.ppt_markup import namilize
 
@@ -62,6 +65,12 @@ class FactDressed(Fact):
 
     # ***
 
+    @property
+    def pk_str(self):
+        return str(self.pk)
+
+    # ***
+
     @property
     def short(self):
         friendly = (
@@ -102,23 +111,31 @@ class FactDressed(Fact):
         set_coloring(was_coloring)
         return friendly_str
 
-    def oid_colorize(self, oid_part, oid_text):
+    # ***
+
+    FACTOID_STYLE = {}
+
+    @classmethod
+    def register_factoid_style(cls, factoid_style=None):
+        """Registers a dictionary of style lists for oid_stylize.
+        """
+        for part, styles in factoid_style.items():
+            errs = ', '.join(verify_colors_attrs(*styles))
+            if errs:
+                emsg = _('Unknown colors or attrs for “{}”: {}').format(part, errs)
+                dob_in_user_warning(emsg)
+        # Nonetheless, can still use even if some/all unknown colors/attrs.
+        cls.FACTOID_STYLE = factoid_style or {}
+
+    def oid_stylize(self, oid_part, oid_text):
         """Stylizes parts of the Factoid with color and emphasis.
         """
-        # FIXME: Turn this into config. (And check BonW vs WonB.)
-        lookup = {
-            'pk': ('grey_78'),
-            'act@gory': ('cornflower_blue', 'bold', 'underlined'),
-            '#': ('grey_78'),
-            'tag': ('dark_olive_green_1b'),
-            '#tag': ('underlined'),
-            'start': ('sandy_brown'),
-            'end': ('sandy_brown'),
-            'to': ('grey_85'),
-            'duration': ('grey_78'),
-        }
-        colorized = colorize(oid_text, *lookup[oid_part])
-        return colorized
+        try:
+            styles = FactDressed.FACTOID_STYLE[oid_part]
+        except KeyError:
+            styles = []
+        stylized = styles and stylize(oid_text, *styles) or oid_text
+        return stylized
 
     # ***
 
@@ -227,6 +244,19 @@ class FactDressed(Fact):
         set_coloring(was_coloring)
         return friendly_tags
 
+    # ***
+
+    TAGS_TUPLE_STYLE = {}
+
+    @classmethod
+    def register_tags_tuples_style(cls, tags_tuples_style=None):
+        """Registers a dictionary of PTK-style styles for tags_tuples.
+        """
+        # (lb): See command in CustomHeaderValues. These two special styles,
+        # 'value-tag-#' and 'value-tag-label', let you style the hash symbol
+        # separately from the tag label. As opposed to the 'value-tag' option.
+        cls.TAGS_TUPLE_STYLE = tags_tuples_style or {}
+
     # NOTE/2020-01-27: (lb): Returns PPT tuple, not something dob knows about.
     # - We could move this method to dob-viewer, to truly decouple.
     #   But then dob-viewer needs to override FactDressed (self.store.fact_cls).
@@ -236,26 +266,22 @@ class FactDressed(Fact):
         hashtag_token='#',
         quote_tokens=False,
         colorful=False,
-        underlined=False,
         split_lines=False,
     ):
 
         def format_tagname(tag):
-            # FIXME/2020-01-28: (lb): make underline and colors configable.
-            underline_fmt = ' underline' if colorful else ''
             tagged = []
             #
+            # (lb): I had ' fg: ' prefix for class name, but not needed.
             tclss_fmt = ' class:tag-{}'.format(namilize(tag.name))
             #
-            token_fmt = 'fg: ' if (colorful or underline_fmt) else ''
-            token_fmt += '#C6C6C6' if colorful else ''
-            token_fmt += underline_fmt
+            token_fmt = ''
+            token_fmt += fetch_tag_part_fmt('value-tag-#')
             token_fmt += tclss_fmt
             tagged.append((token_fmt, hashtag_token))
             #
-            tname_fmt = 'fg: ' if (colorful or underline_fmt) else ''
-            tname_fmt += '#D7FF87' if colorful else ''
-            tname_fmt += underline_fmt
+            tname_fmt = ''
+            tname_fmt += fetch_tag_part_fmt('value-tag-label')
             tname_fmt += tclss_fmt
             tagged.append((tname_fmt, tag.name))
             #
@@ -265,6 +291,14 @@ class FactDressed(Fact):
                 tagged.append(fmt_quote)
             return tagged
 
+        def fetch_tag_part_fmt(style_attr):
+            if not colorful:
+                return ''
+            try:
+                return FactDressed.TAGS_TUPLE_STYLE[style_attr]
+            except KeyError:
+                return ''
+
         # NOTE: The returned string includes leading space if nonempty!
         tagnames = []
         if self.tags:
@@ -289,6 +323,7 @@ class FactDressed(Fact):
         duration = '[{}]'.format(self.format_delta(style=''))
         actegory = self.oid_actegory(omit_empty_actegory=True)
         actegory = actegory or '<i>No activity</i>'
+        # MAYBE: Make cut_width=39 styleable. #styling
         description = self.oid_description(cut_width=39, sep=': ')
         simple_str = (
             '{} {}{}'
