@@ -33,14 +33,17 @@ from nark.helpers.dev.profiling import profile_elapsed
 
 from dob_viewer.ptkui.re_confirm import confirm
 
+from ..config.styling.style_conf import color as styling_color
+from ..config.styling.style_engine import StyleEngine
+
 from ..crud.interrogate import ask_user_for_edits
+
 from ..ptkui.dialog_overlay import show_message
+
 from .action_manager import ActionManager
 from .edits_manager import EditsManager
 from .exceptions import catch_action_exception
-from .styling_config import StylingConfig
 from .update_handler import UpdateHandler
-from .various_styles import color as styling_color
 from .zone_content import ZoneContent
 from .zone_manager import ZoneManager
 
@@ -59,8 +62,8 @@ class Carousel(object):
         dirty_callback,
         dry,
         content_lexer=None,  # Lexer() instance, used by ZoneContent.
-        classes_style=None,  # Style dict, used by all the zone_*.py.
-        matches_style=None,  # Matching logic and container-class map.
+        style_classes=None,  # Style dict, used by all the zone_*.py.
+        rules_confobj=None,  # Matching logic and container-class map.
         no_completion=None,  # act/cat/tag list to not complete/suggest.
     ):
         self.controller = controller
@@ -73,7 +76,7 @@ class Carousel(object):
         )
         self.dry = dry
         self.content_lexer = content_lexer
-        self.setup_styling(classes_style, matches_style)
+        self.setup_styling(style_classes, rules_confobj)
         self.no_completion = no_completion
         self.action_manager = ActionManager(self)
         self.update_handler = UpdateHandler(self)
@@ -101,9 +104,9 @@ class Carousel(object):
         # NOTE: Without the - 2, to account for the '|' borders,
         #       app apparently hangs.
         full_width = click.get_terminal_size()[0] - 2
-        if not self.classes_style['content-width']:
+        if not self.style_classes['content-width']:
             return full_width
-        avail_width = min(self.classes_style['content-width'], full_width)
+        avail_width = min(self.style_classes['content-width'], full_width)
         return avail_width
 
     # ***
@@ -133,33 +136,33 @@ class Carousel(object):
 
     # ***
 
-    def setup_styling(self, classes_style, matches_style):
+    def setup_styling(self, style_classes, rules_confobj):
         """"""
 
         def _setup_styling():
-            setup_classes_style(classes_style)
-            setup_matches_style(matches_style)
+            setup_style_classes(style_classes)
+            setup_rules_confobj(rules_confobj)
 
-        def setup_classes_style(classes_style):
-            if classes_style is None:
-                # HARDCODED/DEFAULT: classes_style default: 'color'.
+        def setup_style_classes(style_classes):
+            if style_classes is None:
+                # HARDCODED/DEFAULT: style_classes default: 'color'.
                 # (lb): The styling_color() method (an alias of various_style.color())
                 # qualifies as a *hardcoded* value (e.g., we could instead call light()
                 # or night()). But this is merely a fallback in case the user cleared
                 # the setting in their configuration, and then for some reason our
-                # load_classes_style() stopped fetching the default first. In fact,
+                # load_style_classes() stopped fetching the default first. In fact,
                 # per that last point, this code is technically unreachable!
                 self.controller.affirm(False)  # Nawgunnhappen.
-                classes_style = styling_color()
-            self.classes_style = classes_style
+                style_classes = styling_color()
+            self.style_classes = style_classes
 
-        def setup_matches_style(matches_style):
-            self.stylability = StylingConfig(matches_style)
+        def setup_rules_confobj(rules_confobj):
+            self.stylability = StyleEngine(rules_confobj)
 
         _setup_styling()
 
     def add_stylable_classes(self, ppt_widget, friendly_name, fact=None):
-        """Apply custom user classes from ~/.config/dob/styling/styles|stylit.conf
+        """Apply custom user classes from ~/.config/dob/styling/styles|rules.conf
         to, e.g., use custom color backgrounds for Facts with matching Category."""
         fact = fact or self.carousel.edits_manager.curr_edit
         return self.stylability.add_stylable_classes(ppt_widget, friendly_name, fact)
