@@ -155,6 +155,14 @@ class StartEndEdit(object):
                 or (newest_changes.pristine == last_undo_or_newest_changes.altered)
             )
 
+            if newest_changes.pristine == last_undo_or_newest_changes.altered:
+                # Nothing changed! We're done here. E.g., given a completed Fact
+                # that is exactly 30 minutes long, if you typed '+30<TAB>' to set
+                # end to 30 minutes after start, if we kept going, the fact would
+                # be marked dirty, but the Diff Fact would not show anything changed.
+                # Then user tries to quit, and dob says they have unsaved work.
+                return
+
             # Mark things dirty (or not).
             self.edits_manager.manage_edited_dirty_flags(newest_changes.altered)
 
@@ -267,7 +275,7 @@ class StartEndEdit(object):
         # "do not automatically squash an out-of-view neighbor Fact to 0!"
         # Let's at least ensure a 1 second minimum squash neighbor width.
         fact_min_delta = 0
-        if 'interval-gap' not in neighbor.dirty_reasons:
+        if not neighbor.is_gap:
             fact_min_delta = int(self.controller.config['time.fact_min_delta'])
             fact_min_delta = max(fact_min_delta, 1)
         min_delta = timedelta(minutes=fact_min_delta)
